@@ -1,12 +1,11 @@
 package MooseX::Runnable::Invocation;
-BEGIN {
-  $MooseX::Runnable::Invocation::AUTHORITY = 'cpan:JROCKWAY';
-}
-$MooseX::Runnable::Invocation::VERSION = '0.08';
+
+our $VERSION = '0.10';
+
 use Moose;
 use MooseX::Types -declare => ['RunnableClass'];
 use MooseX::Types::Moose qw(Str HashRef ArrayRef);
-use List::MoreUtils qw(uniq);
+use List::SomeUtils qw(uniq);
 use Params::Util qw(_CLASS);
 use Class::Load;
 use namespace::autoclean;
